// Account.cxx - part of the murx project
//
// (c) 2004 by Kai Hildebrandt, Thomas Stauss
//
// ---------------------------------------------------------------------
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
// USA.
//
// ---------------------------------------------------------------------

#include <string>
#include <iostream>
#include "Filter.hxx"
#include "Score.hxx"
#include "MoveTo.hxx"
#include "Account.hxx"

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif


Murx::Account::Account ()
{
    // set default values
    name         = "";
    user         = "";
    password     = "";
    server       = "";
    protocol     = "pop3";
    port         = 0;      // will be set in RCParser.yxx
                           // function check_account ()
    use_tls      = false;
    use_starttls = false;
    fingerprint  = "";
    timeout      = 0;   // timeout is either set locally or globally
                        //  0 = not yet set
}


Murx::Account::Account (std::string name, std::string user,
                        std::string password, std::string server,
                        std::string protocol, unsigned int port, bool use_tls,
                        bool use_starttls, std::string fingerprint,
                        unsigned int timeout)
    : name         (name),
      user         (user),
      password     (password),
      server       (server),
      protocol     (protocol),
      port         (port),
      use_tls      (use_tls),
      use_starttls (use_starttls),
      fingerprint  (fingerprint),
      timeout      (timeout)
{
  
}


void Murx::Account::add_account (std::string name, std::string user,
                                 std::string password, std::string server,
                                 std::string protocol, unsigned int port,
                                 bool use_tls, bool use_starttls,
                                 std::string fingerprint, unsigned int timeout)
{
    this->name         = name;
    this->user         = user;
    this->password     = password;
    this->server       = server;
    this->protocol     = protocol;
    this->port         = port;
    this->use_tls      = use_tls;
    this->use_starttls = use_starttls;
    this->fingerprint  = fingerprint;
    this->timeout      = timeout;
}


void Murx::Account::print () const
{
    std::cout << "name         : " << name         << std::endl;
    std::cout << "user         : " << user         << std::endl;
    std::cout << "password     : " << password     << std::endl;
    std::cout << "server       : " << server       << std::endl;
    std::cout << "protocol     : " << protocol     << std::endl;
    std::cout << "port         : " << port         << std::endl;
    std::cout << "use_tls      : " << use_tls      << std::endl;
    std::cout << "use_starttls : " << use_starttls << std::endl;
    std::cout << "fingerprint  : " << fingerprint  << std::endl;
    std::cout << "timeout      : " << timeout      << std::endl;
}


void Murx::Account::clear()
{
    name.clear();
    user.clear();
    password.clear();
    server.clear();
    protocol.clear();
    port = 0;
    use_tls = false;
    use_starttls = false;
    fingerprint.clear();
    timeout = 0;
    
    // vectors
    allows.clear();
    denies.clear();
    scores.clear();
    movetos.clear();
}


std::string Murx::Account::get_name () const
{
    return name;
}
void Murx::Account::set_name (std::string name)
{
    this->name = name;
}


std::string Murx::Account::get_user () const
{
    return user;
}
void Murx::Account::set_user (std::string user)
{
    this->user = user;
}


std::string Murx::Account::get_password () const
{
    return password;
}
void Murx::Account::set_password (std::string password)
{
    this->password = password;
}


std::string Murx::Account::get_server () const
{
    return server;
}
void Murx::Account::set_server (std::string server)
{
    this->server = server;
}


std::string Murx::Account::get_protocol () const
{
    return protocol;
}
void Murx::Account::set_protocol (std::string protocol)
{
    this->protocol = protocol;
}


unsigned int Murx::Account::get_port () const
{
    return port;
}
void Murx::Account::set_port (unsigned int port)
{
    this->port = port;
}


bool Murx::Account::is_using_tls () const
{
    return use_tls;
}
void Murx::Account::set_use_tls (bool use_tls)
{
    this->use_tls = use_tls;
}


bool Murx::Account::is_using_starttls () const
{
    return use_starttls;
}
void Murx::Account::set_use_starttls (bool use_starttls)
{
    this->use_starttls = use_starttls;
}


std::string Murx::Account::get_fingerprint () const
{
    return fingerprint;
}
void Murx::Account::set_fingerprint (std::string fingerprint)
{
    this->fingerprint = fingerprint;
}


unsigned int Murx::Account::get_timeout () const
{
    return timeout;
}
void Murx::Account::set_timeout (unsigned int timeout)
{
    this->timeout = timeout;
}


const std::vector<Murx::Filter>& Murx::Account::get_allows () const
{
    return allows;
}
void Murx::Account::add_allow_rule (Murx::Filter& filter)
{
    allows.push_back (filter);
}


const std::vector<Murx::Filter>& Murx::Account::get_denies () const
{
    return denies;
}
void Murx::Account::add_deny_rule (Murx::Filter& filter)
{
    denies.push_back (filter);
}


const std::vector<Murx::Score>& Murx::Account::get_scores () const
{
    return scores;
}
void Murx::Account::add_score_rule (Murx::Score& score)
{
    scores.push_back (score);
}


const std::vector<Murx::MoveTo>& Murx::Account::get_movetos () const
{
    return movetos;
}
void Murx::Account::add_moveto_rule (Murx::MoveTo& moveto)
{
    movetos.push_back (moveto);
}
