// Account.hxx - part of the murx project
//
// (c) 2004 by Kai Hildebrandt, Thomas Stauss
//
// ---------------------------------------------------------------------
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
// USA.
//
// ---------------------------------------------------------------------

#ifndef MURX_ACCOUNT_HXX
#define MURX_ACCOUNT_HXX

#include <string>
#include "Filter.hxx"
#include "Score.hxx"
#include "MoveTo.hxx"



namespace Murx
{
    class Account
    {
    private:
        /* unique name of the account */
        std::string         name;
        /* username on the mail server */
        std::string         user;
        /* password for user on server */
        std::string         password;
        /* hostname of the mail server */
        std::string         server;
        /* protocol to use for filtering */
        std::string         protocol;
        /* port of the running mail server */
        unsigned int        port;
        /* if true, encrypt the connection via TLS */
        bool                use_tls;
        /* if true, connect normally and start an encrypted session
           via STLS command */
        bool                use_starttls;
        /* the SHA1 or MD5 fingerprint of the certificate from the server */
        std::string         fingerprint;
        /* if this limit is reached, stop trying to connect to server */
        unsigned int        timeout;
        
        std::vector<Filter> allows;
        std::vector<Filter> denies;
        std::vector<Score>  scores;
        std::vector<MoveTo> movetos;

    public:
        //! default constructor
        /*!
          creates an empty account object
        */
        Account ();

        //! Kurzbeschreibung (erscheint oben und unten)
        /*!
          Beschreibung in lang. Taucht nur unten auf!
         */
        Account (std::string  name       , std::string  user        ,
                 std::string  password   , std::string  server      ,
                 std::string  protocol   , unsigned int port        ,
                 bool         use_tls    , bool         use_starttls,
                 std::string  fingerprint, unsigned int timeout      );
        
        void add_account (std::string name       , std::string  user        ,
                          std::string password   , std::string  server      ,
                          std::string protocol   , unsigned int port        ,
                          bool        use_tls    , bool         use_starttls,
                          std::string fingerprint, unsigned int timeout      );

        void            print             () const;

        void            clear             ();

        std::string     get_name          () const;
        void            set_name          (std::string name);

        std::string     get_user          () const;
        void            set_user          (std::string user);

        std::string     get_password      () const;
        void            set_password      (std::string);

        std::string     get_server        () const;
        void            set_server        (std::string server);

        std::string     get_protocol      () const;
        void            set_protocol      (std::string protocol);

        unsigned int    get_port          () const;
        void            set_port          (unsigned int port);

        bool            is_using_tls      () const;
        void            set_use_tls       (bool use_tls);

        bool            is_using_starttls () const;
        void            set_use_starttls  (bool use_starttls);

        std::string     get_fingerprint   () const;
        void            set_fingerprint   (std::string fingerprint);

        unsigned int    get_timeout       () const;
        void            set_timeout       (unsigned int timeout);

        void                       add_allow_rule (Filter& filter);
        const std::vector<Filter>& get_allows     () const;

        void                       add_deny_rule  (Filter& filter);
        const std::vector<Filter>& get_denies     () const;

        void                       add_score_rule (Score& score);
        const std::vector<Score>&  get_scores     () const;

        void                       add_moveto_rule (MoveTo& moveto);
        const std::vector<MoveTo>& get_movetos     () const;
    };

} /* namespace Murx */

#endif /* MURX_ACCOUNT_HXX */
