// Header.cxx - part of the murx project
//
// (c) 2004 by Thomas Stauss, Kai Hildebrandt
//
// ---------------------------------------------------------------------
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
// USA.
//
// ---------------------------------------------------------------------

#include <string>

#include "Header.hxx"
#include "Match.hxx"
#include "Session.hxx"

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif


Murx::Header::Header ()
    : size               (0),
      maxsize            (0),
      minsize            (0),
      // initialize subject_line_index with an impossible value
      // so we can see whether there was a subject line or not
      subject_line_index (-1),
      total_score        (0),
      action             (Murx::Session::ACCOUNT_FILTERING_FINISHED),
      testmode           (false),
      maxlength          (0),
      rfc2822_conformant  (true)
{
//    std::cerr << "new Header created" << std::endl;
}


Murx::Header::~Header ()
{
//    std::cerr << "Header destroyed" << std::endl;
}


void Murx::Header::set_id (unsigned int id)
{
    this->id = id;
}
unsigned int Murx::Header::get_id ()
{
    return id;
}


void Murx::Header::set_account (unsigned int account)
{
    this->account = account;
}
unsigned int Murx::Header::get_account ()
{
    return account;
}


void Murx::Header::set_size (unsigned int size)
{
    this->size = size;
}
unsigned int Murx::Header::get_size ()
{
    return size;
}


void Murx::Header::set_maxsize (unsigned int maxsize)
{
    this->maxsize = maxsize;
}
unsigned int Murx::Header::get_maxsize ()
{
    return maxsize;
}


void Murx::Header::set_minsize (unsigned int minsize)
{
    this->minsize = minsize;
}
unsigned int Murx::Header::get_minsize ()
{
    return minsize;
}


void Murx::Header::set_subject_line_index (int index)
{
    subject_line_index = index;
}
int Murx::Header::get_subject_line_index ()
{
    return subject_line_index;
}


void Murx::Header::set_total_score (int value)
{
    total_score = value;
}
int Murx::Header::get_total_score ()
{
    return total_score;
}


void Murx::Header::set_action (int action)
{
    this->action = action;
}
int Murx::Header::get_action ()
{
    return action;
}


void Murx::Header::set_testmode (bool testmode)
{
    this->testmode = testmode;
}
bool Murx::Header::get_testmode ()
{
    return testmode;
}


void Murx::Header::set_maxlength (unsigned int maxlength)
{
    this->maxlength = maxlength;
}
unsigned int Murx::Header::get_maxlength ()
{
    return maxlength;
}


void Murx::Header::set_rfc2822_conformant (bool value)
{
    this->rfc2822_conformant = value;
}
bool Murx::Header::is_rfc2822_conformant ()
{
    return rfc2822_conformant;
}


void Murx::Header::set_folder (std::string folder)
{
    this->folder = folder;
}
std::string Murx::Header::get_folder ()
{
    return folder;
}


void Murx::Header::add_match (Murx::Match& match)
{
    match_list.push_back (match);
}
const std::vector<Murx::Match>& Murx::Header::get_match_list () const
{
    return match_list;
}
void Murx::Header::set_match_list (std::vector<Murx::Match>& match_list)
{
    // expensive copy!
    this->match_list = match_list;
}


std::string Murx::Header::get_message_id ()
{
    return message_id;
}
void Murx::Header::set_message_id (std::string str)
{
    message_id = str;
}


void Murx::Header::set_from (std::string str)
{
    from = str;
}
std::string Murx::Header::get_from ()
{
    return from;
}


void Murx::Header::add_to (std::string str)
{
    to.push_back (str);
}
const std::vector<std::string>& Murx::Header::get_to () const
{
    return to;
}


void Murx::Header::add_cc (std::string str)
{
    cc.push_back (str);
}
const std::vector<std::string>& Murx::Header::get_cc () const
{
    return cc;
}


std::string Murx::Header::get_subject ()
{
    return subject;
}
void Murx::Header::set_subject (std::string str)
{
    subject = str;
}


std::string Murx::Header::get_date ()
{
    return date;
}
void Murx::Header::set_date (std::string str)
{
    date = str;
}


const std::vector<std::string>& Murx::Header::get_header_lines () const
{
    return header_line;
}
void Murx::Header::add_header_line (std::string str)
{
    header_line.push_back (str);
}


const std::vector<std::string>& Murx::Header::get_body_lines () const
{
    return body_line;
}
void Murx::Header::add_body_line (std::string str)
{
    body_line.push_back (str);
}
