// Header.hxx - part of the murx project
//
// (c) 2004 by Thomas Stauss, Kai Hildebrandt
//
// ---------------------------------------------------------------------
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
// USA.
//
// ---------------------------------------------------------------------

#ifndef MURX_HEADER_HXX
#define MURX_HEADER_HXX

#include <string>
#include <vector>
#include "Match.hxx"


namespace Murx
{
    class Header
    {
    protected:
        // id of this mail on mailserver
        unsigned int id;
        // vector-index of the account in session
        unsigned int account;

        // This fields are for printing out information about matches
        // of a rule (patterns and sizes).
        
        // size of this mail, header + body
        unsigned int       size;
        // rule local maxsize
        unsigned int       maxsize;
        // rule local minsize
        unsigned int       minsize;
        // header line vector-index containing the subject
        int                subject_line_index;
        // total score of this mail
        int                total_score;
        // action which should be taken
        int                action;
        // testmode set?
        bool               testmode;

        // length of longest line from header
        unsigned int       maxlength;

        // is message rfc2822-conformant?
        bool               rfc2822_conformant;

        // folder to move message to (MOVETO rule only)        
        std::string        folder;

        // container for matched patterns
        std::vector<Match> match_list;

        //
        // begin headerfield containers
        //
        //std::string              return_path;
        //std::vector<std::string> received;
        std::string              message_id;
        std::string              from;
        std::vector<std::string> to;
        std::vector<std::string> cc;
        std::string              subject;
        std::string              date;
        //std::string              user_agent;
        // contains the whole header
        std::vector<std::string> header_line;
        // can contain body lines
        std::vector<std::string> body_line;
        //
        // end headerfield containers
        //
    
    public:
        Header ();
        ~Header();
        
        void                            set_id           (unsigned int id);
        unsigned int                    get_id           ();
        
        void                            set_account      (unsigned int account);
        unsigned int                    get_account      ();

        //
        // match containers
        //
        void                            set_size         (unsigned int size);
        unsigned int                    get_size         ();
        
        void                            set_maxsize      (unsigned int maxsize);
        unsigned int                    get_maxsize      ();
        
        void                            set_minsize      (unsigned int minsize);
        unsigned int                    get_minsize      ();
        
        void                            set_subject_line_index (int index);
        int                             get_subject_line_index ();
        
        void                            set_total_score  (int value);
        int                             get_total_score  ();
        
        void                            set_action       (int action);
        int                             get_action       ();
        
        void                            set_testmode     (bool testmode);
        bool                            get_testmode     ();

        void                            set_maxlength    (unsigned int maxlength);
        unsigned int                    get_maxlength    ();

        void                            set_rfc2822_conformant (bool value);
        bool                            is_rfc2822_conformant ();
        
        void                            set_folder       (std::string folder);
        std::string                     get_folder       ();

        void                            add_match        (Match& match);
        void                            set_match_list   (std::vector<Match>& match_list);
        const std::vector<Match>&       get_match_list   () const;

        //
        // headerfield containers
        //
        std::string                     get_message_id   ();
        void                            set_message_id   (std::string str);
        
        void                            set_from         (std::string str);
        std::string                     get_from         ();
        
        void                            add_to           (std::string str);
        const std::vector<std::string>& get_to           () const;
        
        void                            add_cc           (std::string str);
        const std::vector<std::string>& get_cc           () const;
        
        std::string                     get_subject      ();
        void                            set_subject      (std::string str);
        
        std::string                     get_date         ();
        void                            set_date         (std::string str);
        
        const std::vector<std::string>& get_header_lines () const;
        void                            add_header_line  (std::string str);
        
        const std::vector<std::string>& get_body_lines   () const;
        void                            add_body_line    (std::string str);
    };
}

#endif /* MURX_HEADER_HXX */
