// Match.hxx - part of the murx project
//
// (c) 2004 by Thomas Stauss, Kai Hildebrandt
//
// ---------------------------------------------------------------------
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
// USA.
//
// ---------------------------------------------------------------------

#ifndef MURX_MATCH_HXX
#define MURX_MATCH_HXX

#include <string>
#include <vector>
#include "MatchData.hxx"


namespace Murx
{
    // This class stores a set of matches and an action
    class Match
    {
    private:
        // which action was applied to message?
        // one of: - allowed
        //         - deleted
        //         - added score +50
        //         - moved to folder "bla"
        std::string        action;

        // did all patterns of the filter match?
        bool               complete_match;

        // matches for applying the action above
        std::vector<MatchData> matches;

    public:
        Match();

        std::string        get_action         () const;
        void               set_action         (std::string action);

        //! Did the filter match completely?
        bool               was_complete_match () const;
        void               set_complete_match (bool value);

        //! Add a match (MatchData)
        void               add                (MatchData match);
        //void               add                (MatchData& match);

        //! Get a match (MatchData)
        const MatchData&   at                 (const unsigned int i) const;

        //! Returns the count of patterns stored in vector matches.
        const unsigned int size               () const;
    };
}

#endif /* MURX_MATCH_HXX */
