// MatchData.cxx - part of the murx project
//
// (c) 2005 by Kai Hildebrandt
//
// ---------------------------------------------------------------------
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
// USA.
//
// ---------------------------------------------------------------------

#include "MatchData.hxx"


namespace Murx
{
    MatchData::MatchData()
    {
        // defaults
        line                       = 0;
        start_pos                  = 0;
        count                      = 0;
        expression                 = "";
        matched_normalized_subject = false;
        is_header_line             = true;
        negativity                 = false;
    }


    MatchData::MatchData (unsigned int line,
                          unsigned int start_pos,
                          unsigned int count,
                          std::string expression,
                          bool matched_normalized_subject,
                          bool is_header_line)
        : line                       (line),
          start_pos                  (start_pos),
          count                      (count),
          expression                 (expression),
          matched_normalized_subject (matched_normalized_subject),
          is_header_line             (is_header_line),
          negativity                 (false)
    {
    }
        

    MatchData::MatchData (std::string expression)
        : expression     (expression),
          negativity     (true)
    {
    }


    const unsigned int MatchData::get_line() const
    {
        return line;
    }


    const unsigned int MatchData::get_start_pos() const
    {
        return start_pos;
    }


    const unsigned int MatchData::get_count() const
    {
        return count;
    }


    const std::string MatchData::get_expression() const
    {
        return expression;
    }


    const bool MatchData::get_matched_normalized_subject() const
    {
        return matched_normalized_subject;
    }


    const bool MatchData::get_is_header_line() const
    {
        return is_header_line;
    }


    const bool MatchData::get_negativity() const
    {
        return negativity;
    }

}   // namespace Murx
