// MatchData.hxx - part of the murx project
//
// (c) 2005 by Kai Hildebrandt
//
// ---------------------------------------------------------------------
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
// USA.
//
// ---------------------------------------------------------------------

#ifndef MURX_MATCHDATA_HXX
#define MURX_MATCHDATA_HXX

#include <string>


namespace Murx
{
    // This class stores information about the match of
    // a regular expression.
    class MatchData
    {
    private:
        // The line number (class header) of the header line
        // in which the expression matched.
        unsigned int line;

        // Start position of the matched string in the header line.
        unsigned int start_pos;

        // The matched string is "count" chars long.
        unsigned int count;

        // Contains the regular expression which matched the line.
        std::string  expression;

        // Did expression matched normalized subject?
        bool         matched_normalized_subject;

        // Matched a header line (and not a body line)?
        bool         is_header_line;

        // Flag for negative expression
        bool         negativity;

    public:
        MatchData();

        // Constructor for positive matches
        MatchData (unsigned int line,
                   unsigned int start_pos,
                   unsigned int count,
                   std::string  expression,
                   bool         matched_normalized_subject,
                   bool         is_header_line);
        
        // Constructor for negative matches
        MatchData (std::string expression);

        // >>> getter
        const unsigned int get_line                       () const;
        const unsigned int get_start_pos                  () const;
        const unsigned int get_count                      () const;
        const std::string  get_expression                 () const;
        const bool         get_matched_normalized_subject () const;
        const bool         get_is_header_line             () const;
        const bool         get_negativity                 () const;
        // <<< getter
    };
}

#endif /* MURX_MATCHDATA_HXX */
