// MoveTo.cxx - part of the murx project
//
// (c) 2004 by Kai Hildebrandt
//
// ---------------------------------------------------------------------
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
// USA.
//
// ---------------------------------------------------------------------

#include <string>
#include <vector>
#include <iostream>
#include "i18n.hxx"
#include "Filter.hxx"
#include "MoveTo.hxx"

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif


Murx::MoveTo::MoveTo ()
{
}


Murx::MoveTo::MoveTo (const char* expression, bool ignore_case,
                      bool negativity, bool only_check_body_lines,
                      std::string folder)
    : Filter (expression, ignore_case, negativity, only_check_body_lines)
{
    this->folder = folder;
}


// copy constructor
Murx::MoveTo::MoveTo (Murx::Filter& filter)
{
    const std::vector<Murx::Rule>& rules = filter.get_rules ();

    // copy all filter rules into MoveTo object
    for (unsigned int i = 0; i < rules.size (); i++)
    {
        this->add_rule (rules.at(i).expression.c_str(),
                        rules.at(i).ignore_case,
                        rules.at(i).negativity,
                        rules.at(i).only_check_body_lines);
    }
}


Murx::MoveTo::~MoveTo ()
{
}


void Murx::MoveTo::print () const
{
    std::cout << _("  folder: ") << folder << std::endl;
    static_cast<const Murx::Filter*> (this)->print ();
}


std::string Murx::MoveTo::get_folder () const
{
    return (this->folder);
}
void Murx::MoveTo::set_folder (std::string folder)
{
    this->folder = folder;
}
