// POP3Protocol.hxx - part of the murx project
//
// (c) 2004 by Thomas Stauss
//
// ---------------------------------------------------------------------
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
// USA.
//
// ---------------------------------------------------------------------

#ifndef MURX_POP3PROTOCOL_HXX
#define MURX_POP3PROTOCOL_HXX

#include <sstream>

#include "Account.hxx"
#include "Header.hxx"
#include "Protocol.hxx"
#include "RFC822Parser.hxx"
#include "Socket.hxx"


namespace Murx
{
    class POP3Protocol : public Protocol
    {
    private:
        // account data including all filters
        Account      account;

        // network socket
        Net::Socket  *sock;

        std::string str;
        int         messages_available;
        int         current_message;

        RFC822Parser* header_parser;
    
        void read_line           (std::string& str);

        void fetch_message_count (); // throws Protocol

        bool is_request_ok       (std::string server_answer);

    public:
        POP3Protocol ();
        POP3Protocol (const Account &account);
        ~POP3Protocol();

        // >>> interface from Protocol.hxx

        //! Creates a connection to the POP3 server defined in account.
        /*! It also initiates encryption via TLS if desired.
         */
        void connect           (); // throws Protocol

        //! Sends username and password to the POP3 server.
        void authenticate      (); // throws UnknownAccount, LoginError

        //! Wrapper for the sequence connect(); authenticate(); fetch_message_count().
        void login             (); // calls connect(), authenticate() and
        //                            fetch_message_count()

        //! Quits the POP3 session.
        void logout            (); // throws Protocol

        //! Get the next RFC822 header optionally with some body lines.
        bool get_next_header   (Header& header, const int body_lines = 0);
        //                      throws Protocol

        //! Get the amount of recent messages on the POP3 server.
        int  get_message_count () const;

        //! Remove the message with ID id on the server.
        void delete_message    (unsigned int id); // throws Protocol

        // <<< interface from Protocol.hxx
    };
}

#endif /* MURX_POP3PROTOCOL_HXX */
