// Preferences.hxx - part of the murx project
//
// (c) 2004 by Kai Hildebrandt, Thomas Stauss
//
// ---------------------------------------------------------------------
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
// USA.
//
// ---------------------------------------------------------------------

#ifndef MURX_PREFERENCES_HXX
#define MURX_PREFERENCES_HXX

#include <vector>
#include <string>
#include "Account.hxx"
#include "Filter.hxx"
#include "Score.hxx"
#include "MoveTo.hxx"
//#include "Exceptions.hxx"


namespace Murx
{
    class Preferences
    {
    private:
        Preferences ();
        ~Preferences();
    
        static Preferences*   preferences;
    
        std::vector<Account>  accounts;

        // path to headerfile
        std::string     headerfile;
        // path to logfile
        std::string     logfile;
        // path to network logfile
        std::string     netlog;
        // what should I write in the logfile?
        unsigned int    loglevel;

        // what to do with non-RFC822-conformant mails?
        std::string     nonconformant_action;   // either DENY or MOVETO
        std::string     nonconformant_folder;

        // remove non alphanumeric characters?
        bool            normalize_subject;
        // global value for case sensivity
        bool            ignore_case;
        // global value for test
        bool            testmode;
        // count of bodylines which should be read additionally to the header
        unsigned int    body_lines;
        // delete duplicate message ids?
        bool            delete_duplicates;
        // should I return amount of remaining mails?
        bool            return_remaining;
        // default highscore (100)
        int             highscore;
        // default: 60 (seconds)
        unsigned int    global_timeout;
        // default: 0 = off
        unsigned int    maxsize_allow;
        // default: 0 = off
        unsigned int    maxsize_deny;
        // default: 0 = off
        unsigned int    maxlength;

    public:
        static Preferences*         get_instance ();
        static void                 destroy      ();

        void                        print        () const;

        void                        add_account  (Account &account);
        const std::vector<Account>& get_accounts () const;
        Account&                    get_account  (std::string name,
                                                  unsigned int line = 0);

        void         set_headerfile        (std::string headerfile);
        std::string  get_headerfile        () const;

        void         set_logfile           (std::string logfile);
        std::string  get_logfile           () const;

        void         set_netlog            (std::string netlog);
        std::string  get_netlog            () const;

        void         set_loglevel          (unsigned int loglevel);
        unsigned int get_loglevel          () const;

        void         set_nonconformant_action (std::string action);
        std::string  get_nonconformant_action () const;

        void         set_nonconformant_folder (std::string folder);
        std::string  get_nonconformant_folder () const;

        void         set_normalize_subject (bool yes_or_no);
        bool         get_normalize_subject () const;

        void         set_ignore_case       (bool yes_or_no);
        bool         get_ignore_case       () const;

        void         set_testmode          (bool yes_or_no);
        bool         get_testmode          () const;

        void         set_body_lines        (unsigned int body_lines);
        unsigned int get_body_lines        () const;

        void         set_delete_duplicates (bool yes_or_no);
        bool         get_delete_duplicates () const;

        void         set_return_remaining  (bool yes_or_no);
        bool         get_return_remaining  () const;

        void         set_highscore         (int highscore);
        int          get_highscore         () const;

        void         set_global_timeout    (unsigned int global_timeout);
        unsigned int get_global_timeout    () const;

        void         set_maxsize_allow     (unsigned int maxsize_allow);
        unsigned int get_maxsize_allow     () const;

        void         set_maxsize_deny      (unsigned int maxsize_deny);
        unsigned int get_maxsize_deny      () const;

        void         set_maxlength         (unsigned int maxlength);
        unsigned int get_maxlength         () const;
    };

} /* namespace Murx */

#endif /* MURX_PREFERENCES_HXX */
