// Protocol.hxx - part of the murx project
//
// (c) 2004 by Thomas Stauss
//
// ---------------------------------------------------------------------
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
// USA.
//
// ---------------------------------------------------------------------

#ifndef MURX_PROTOCOL_HXX
#define MURX_PROTOCOL_HXX

#include <string>
#include <vector>

#include "Header.hxx"


namespace Murx
{
    class Protocol
    {
    public:
        virtual ~Protocol              () {};

        //! Creates a connection to the server defined in account.
        /*! It also initiates encryption via TLS if desired.
         */
        virtual void connect           () = 0;

        //! Sends username and password to the server.
        virtual void authenticate      () = 0;

        //! Wrapper for the sequence connect(); authenticate(); fetch_message_count().
        virtual void login             () = 0;

        //! Send a logout command to server.
        virtual void logout            () = 0;

        //! Get the next RFC822 header.
        virtual bool get_next_header   (Header& header,
                                        const int body_lines = 0) = 0;

        //! Get the amount of recent messages on the server.
        virtual int  get_message_count () const = 0;

        //! Remove the message with ID id on the server.
        virtual void delete_message    (unsigned int id) = 0;
        
        //! Fills the given vector with the name of all supported protocols.
        static void  get_supported_protocols (
            std::vector<std::string> &protocols)
            {
                if (protocols.size())
                    protocols.clear();
                
                protocols.push_back ("POP3");
                protocols.push_back ("IMAP");
            }
    };
}

#endif /* MURX_PROTOCOL_HXX */
