// RCParser.hxx - wrapper class for the configfile parser to provide a
//                beautyful interface
//
// (c) 2004 by Kai Hildebrandt
//
// ---------------------------------------------------------------------
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
// USA.
//
// ---------------------------------------------------------------------
//

#ifndef MURX_RCPARSER
#define MURX_RCPARSER

#include <iostream>
#include <sstream>
#include "Filter.hxx"
#include "Account.hxx"

#undef yyFlexLexer
#define yyFlexLexer rcFlexLexer
#include <FlexLexer.h>


// defined in RCParser.yxx
extern FlexLexer*    rclexer;
extern Murx::Filter  rc_filter;
extern Murx::Account rc_account;

extern int rc_line;

extern int rcparse (void* preferences);


namespace Murx
{
    class RCParser
    {
    private:
        // rclexer is global :-|
        
    public:
        RCParser ()
        {
            rclexer = new rcFlexLexer (0, 0);
        }
        RCParser (std::istream* in)
        {
            rclexer = new rcFlexLexer (in, 0);
        }
        RCParser (std::istream* in, std::ostream* out)
        {
            rclexer = new rcFlexLexer (in, out);
        }
        ~RCParser ()
        {
            // free flex scanner
            delete rclexer;
        }
        
        static void parse (void* preferences)
        {
            // init values
            rc_line = 0;

            // The function rcparse returns 0 if successful, 1 otherwise
            // (syntax error). But we use exceptions for error handling
            // so we don't need to check the return value.
            //
            rcparse (preferences);
        }
    };

} /* namespace Murx */

#endif /* MURX_RCPARSER */
