// RFC822Parser.hxx - wrapper class for the rfc822 parser to provide a
//                    beautyful interface
//
// (c) 2004 by Kai Hildebrandt
//
// ---------------------------------------------------------------------
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
// USA.
//
// ---------------------------------------------------------------------
//

#ifndef MURX_RFC822PARSER
#define MURX_RFC822PARSER

#include <sstream>

// Create a new class rfc822FlexLexer derived from FlexLexer
#undef yyFlexLexer
#define yyFlexLexer rfc822FlexLexer
#include <FlexLexer.h>

// defined in RFC822Parser.yxx
extern FlexLexer*   rfc822lexer;
extern unsigned int rfc822_last_hf;

// defined in RFC822Scanner.lxx
extern int          rfc822_line;
extern int          rfc822_index;
extern unsigned int rfc822_maxlength;

// defined in RFC822Parser.yxx
extern int rfc822parse (void* header);


namespace Murx
{
    class RFC822Parser
    {
    private:
        // FlexLexer* rfc822lexer is global :-|
        
    public:
        RFC822Parser ()
        {
            rfc822lexer = new rfc822FlexLexer (0, 0);
        }
        RFC822Parser (std::istream* in)
        {
            rfc822lexer = new rfc822FlexLexer (in, 0);
        }
        RFC822Parser (std::istream* in, std::ostream* out)
        {
            rfc822lexer = new rfc822FlexLexer (in, out);
        }
        ~RFC822Parser ()
        {
            delete rfc822lexer;
        }
        
        static void parse (void* header)
        {
            // initialize global parser variables
            
            // line no
            rfc822_line = -1;

            // line no (without folded lines, is less or equal rfc822_line)
            rfc822_index = -1;

            // length of longest header line
            rfc822_maxlength = 0;

            // constant for WAS_NOTHING,
            // defined in RFC822Parser.yxx
            rfc822_last_hf = 0;

            // rfc822parse returns 0 if successful, 1 otherwise (syntax error)
            rfc822parse (header);
        }
    };

} /* namespace Murx */

#endif /* MURX_RFC822PARSER */
