// SIGINTHandler.cxx - part of the murx project
//
// (c) 2005 Kai Hildebrandt
//
// ---------------------------------------------------------------------
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
// USA.
//
// ---------------------------------------------------------------------


#include <csignal>     // sig_atomic_t
#include <cassert>
#include <cstdlib>     // exit()

#include "Logger.hxx"
#include "Utils.hxx"   // int_to_string()
#include "i18n.hxx"    // _()
#include "murx.hxx"    // Murx::ABORTED

#include "EventHandler.hxx"
#include "SIGINTHandler.hxx"

#ifndef logger_logfile
#define logger_logfile Murx::Logger::get_instance(Murx::Logger::Logfile)
#endif


// hook method
int Murx::SIGINTHandler::handle_signal (int signum)
{
    // exits program if signal is not SIGINT
    assert (signum == SIGINT);

    // log a message
    std::string logmessage = _("error: program abort due to signal ")
        + Murx::Utils::int_to_string(signum)
        + " (SIGINT)";
    logger_logfile->log(logmessage, Murx::Logger::ERROR);

    // exit program
    exit (Murx::ABORTED);
}
