// SignalHandler.cxx - part of the murx project
//
// (c) 2005 Kai Hildebrandt
//
// ---------------------------------------------------------------------
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
// USA.
//
// ---------------------------------------------------------------------


#include <cstdlib>
#include <csignal>

#include "EventHandler.hxx"
#include "SignalHandler.hxx"


// private

// SignalHandler is a singleton object and
// will be only allocated once. This variable
// stores the pointer to the object.
Murx::SignalHandler* Murx::SignalHandler::instance = 0;

// table for signal handlers
Murx::EventHandler* Murx::SignalHandler::signal_handlers[NSIG];

// private constructor ...
Murx::SignalHandler::SignalHandler()
{
}

// ... and destructor
Murx::SignalHandler::~SignalHandler()
{
}

void Murx::SignalHandler::dispatcher (int signum)
{
    // perform a sanity check...
    if (SignalHandler::signal_handlers[signum] != 0)
    {
        // ...and dispatch the handler's hook method.
        SignalHandler::signal_handlers[signum]->handle_signal(signum);
    }
}


// public

// get a pointer to the SignalHandler object
Murx::SignalHandler* Murx::SignalHandler::get_instance()
{
    if (instance == 0)
        instance = new Murx::SignalHandler ();
    
    return instance;
}


Murx::EventHandler*
Murx::SignalHandler::register_handler (int signum,
                                       EventHandler* eh)
{
    // copy the <old_eh> from the <signum> slot in 
    // the <signal_handlers_> table.
    EventHandler *old_eh =
        SignalHandler::signal_handlers[signum];
    
    // store <eh> into the <signum> slot in the
    // <signal_handlers_> table.
    SignalHandler::signal_handlers[signum] = eh;
    
    // Register the <dispatcher> to handle this
    // <signum>.
    struct sigaction sa;
    sa.sa_handler = SignalHandler::dispatcher;
    sigemptyset (&sa.sa_mask);
    sa.sa_flags = 0;
    sigaction (signum, &sa, 0);
    
    return old_eh;
}


int Murx::SignalHandler::remove_handler (int signum)
{
    if (signal_handlers[signum] == 0)
        return 0;  // no handler registered for <signum>

    signal_handlers[signum] = 0;
    return 1;  // OK, removed handler
}
