// SignalHandler.hxx - part of the murx project
//
// (c) 2005 Kai Hildebrandt
//
// ---------------------------------------------------------------------
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
// USA.
//
// ---------------------------------------------------------------------

// pattern for signals in OO from:
// http://www.cs.wustl.edu/~schmidt/signal-patterns.html

#ifndef MURX_SIGNALHANDLER_HXX
#define MURX_SIGNALHANDLER_HXX

#include <csignal>   // NSIG
#include "EventHandler.hxx"


namespace Murx
{
    class SignalHandler
    {
    public:
        // singleton entry point
        static SignalHandler* get_instance();

        // register an event handler <eh> for <signum>
        // and return a pointer to any existing <EventHandler>
        // that was previously registered to handle <signum>.
        EventHandler* register_handler (int signum,
                                        EventHandler *eh);

        // remove the <EventHandler> for <signum>
        // by setting the slot in the <signal_handlers>
        // table to NULL.
        int remove_handler (int signum);

    private:
        // singleton
        SignalHandler();
        ~SignalHandler();

        static SignalHandler* instance;

        // entry point adapter installed into <sigaction>
        // (must be a static method or a stand-alone
        // extern "C" function).
        static void dispatcher (int signum);

        // table of pointers to concrete <EventHandler>s
        // registered by applications. NSIG is the number of
        // signals defined in </usr/include/sys/signal.h>
        static EventHandler* signal_handlers[NSIG];
    };
}

#endif /* MURX_SIGNALHANDLER_HXX */
