// Socket.hxx - part of the murx project
//
// (c) 2004 by Thomas Stauss
//
// ---------------------------------------------------------------------
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
// USA.
//
// ---------------------------------------------------------------------

#ifndef MURX_SOCKET_HXX
#define MURX_SOCKET_HXX

#include <string>
extern "C"
{
#include <sys/time.h>   // struct timeval
}
#include "Exceptions.hxx"


namespace Murx
{
namespace Net
{
    class Socket
    {
    protected:
        // timeout in seconds
        unsigned int            timeout;

        // used by select () (after login)
        // for timeout handling:

        // descriptor-set for timeouts
        fd_set                  fds;

        // timeout structure (sec and usec)
        struct timeval          tv;

    public:
        virtual ~Socket() {}

        virtual void            connect     ()                         = 0;
        virtual void            close       ()                         = 0;
        virtual int             read        (std::string &str)         = 0;
        virtual void            write       (const std::string str)    = 0;
        virtual void            write       (const char *str)          = 0;
        virtual void            write       (const char *str, int len) = 0;
        virtual unsigned int    get_timeout ()                         = 0;
    };
}
}

#endif /* MURX_SOCKET_HXX */
