// TCPSocket.hxx - part of the murx project
//
// (c) 2004 by Thomas Stauss
//
// ---------------------------------------------------------------------
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
// USA.
//
// ---------------------------------------------------------------------

#ifndef MURX_TCPSOCKET_HXX
#define MURX_TCPSOCKET_HXX

#include <string>

#ifdef WIN32
    #include <Winsock2.h>
#else
    #include <sys/types.h>
    #include <sys/socket.h>
    #include <netdb.h>
    #include <netinet/in.h>
    #include <arpa/inet.h>
    #include <unistd.h>
    #include <sys/time.h>
#endif

#include "Socket.hxx"
#include "Exceptions.hxx"


namespace Murx
{
    namespace Net
    {
        class TCPSocket : public Socket
        {
        private:
            // Socket-descriptor
#ifdef WIN32
            SOCKET        sock;
#else
            int           sock;
#endif
            // Data concerning the server (like IP, port, ...)
            sockaddr_in    serverInfo;
            // indicating if the socket is connected or not
            bool           connected;
            
        public:
            TCPSocket (std::string server,
                       unsigned int port,
                       unsigned int timeout);

            ~TCPSocket() {}

            //! Connect to a remote host
            void           connect ();
            //! Close connection
            void           close ();
            //! Read data from remote host
            int            read (std::string &str);
            
            //! Write the string stored in 'str' to the remote host
            void           write (const std::string str);
            
            void           write (const char *str);
            //! Write 'len' bytes of the string stored in 'str' to the remote host
            void           write (const char *str, int len);
            /*! Return the socket-file descriptor
             *  A return value of -1 indicates that there is no socket-fd
             */
            int            get_socket();

            //! Returns 'true' if the socket is connected, else 'false'
            bool           is_connected ();
            
            unsigned int   get_timeout ();
        };
    }
}

#endif /* MURX_TCPSOCKET_HXX */
