// TLSSocket.hxx - part of the murx project
//
// (c) 2004 by Thomas Stauss
//
// ---------------------------------------------------------------------
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
// USA.
//
// ---------------------------------------------------------------------

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#if USE_OPENSSL

#ifndef MURX_TLSSOCKET_HXX
#define MURX_TLSSOCKET_HXX

#include <string>

#include <openssl/ssl.h>

#include "Socket.hxx"
#include "TCPSocket.hxx"
#include "Exceptions.hxx"
#include <sys/time.h>


namespace Murx
{
namespace Net
{
    class TLSSocket : public Socket
    {
    private:
        Net::TCPSocket *sock;
        SSL_METHOD           *meth;
        SSL_CTX              *ssl_ctx;
        SSL                  *ssl;

        std::string          fingerprint;

        void                 tls_init        ();
        std::string          get_fingerprint (std::string type);

    public:
        TLSSocket (const std::string server,
                   const unsigned int port,
                   unsigned int timeout,
                   std::string fingerprint);

        TLSSocket (Net::TCPSocket *sock, std::string fingerprint);

        ~TLSSocket();

        void         connect     ();
        void         close       ();
        int          read        (std::string &str);
        void         write       (const std::string str);
        void         write       (const char *str);
        void         write       (const char *str, int len);
        unsigned int get_timeout ();
    };
}
}

#endif /* MURX_TLSSOCKET_HXX */

#endif /* USE_OPENSSL */
