// Utils.hxx - some useful functions, pulled out of the global namespace
//
// (c) 2004 by Kai Hildebrandt
//
// ---------------------------------------------------------------------
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
// USA.
//
// ---------------------------------------------------------------------

#ifndef MURX_UTILS_HXX
#define MURX_UTILS_HXX

#include <string>
#include <vector>


#ifdef HAVE_CONFIG_H
#include "config.h"
#endif



namespace Murx
{
    class Utils
    {
    private:
        // Helper for expand_cmd_subst ()
        // Executes the given command in a subshell
        static std::string exec_shell (std::string command, unsigned int line);
        
    public:
        //! Checks whether the given string is a valid (sha|md5) fingerprint
        static bool check_fingerprint (const std::string fingerprint);
        
        //! Cuts off first and last character of a given string.
        /*! Used to delete leading and trailing " of a string parameter.
         *  The string must have at least 3 characters including its
         *  doublequotes, e.g. "a" (length: 3).
         */
        static void chop (std::string& str);

        //! Get all command substitutions like `command` and execute them.
        /*! Replace command string with the output of command.
         */
        static void expand_cmd_subst (std::string& str, unsigned int line);

        //! Substitutes any environment variables with its value.
        static void expand_env_vars (std::string& str, unsigned int line);

        //! Do expansion of command substitution and environment variables
        static void expand_path (std::string& str, unsigned int line);

        //! Translates the given int value into a string
        static std::string int_to_string (int value);

        //! Remove any non-alphanumeric characters in the given string.
        static void normalize_subject (std::string& str);

        //! Remove the leading blanks in a string.
        static void remove_leading_blanks (std::string& str);

        //! Remove the trailing blanks in a string.
        static void remove_trailing_blanks (std::string& str);

        //! Split a string into a vector of strings.
        static void split (const std::string& str,
                           const char sep,
                           std::vector<std::string>& vec);

        //! Convert string to lower case.
        static void tolower (std::string& str);

        //! Remove leading and trailing blanks of a string.
        static void trim (std::string& str);
    };

} /* namespace Murx */


#endif /* MURX_UTILS_HXX */
